@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Copyright 2018-2022 Polyaxon, Inc.
+# Copyright 2018-2023 Polyaxon, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 
 from typing import TYPE_CHECKING, Any
 
-from polyaxon import tracking
+from traceml import tracking
 from traceml.exceptions import TracemlException
 from traceml.integrations.tensorboard import Logger
 
